@@ -79,7 +79,7 @@ static sqlcipher_provider *default_provider = NULL;
 
 static sqlite3_mutex* sqlcipher_static_mutex[SQLCIPHER_MUTEX_COUNT];
 static FILE* sqlcipher_log_file = NULL;
-static volatile int sqlcipher_log_logcat = 0;
+static volatile int sqlcipher_log_device = 0;
 static volatile unsigned int sqlcipher_log_level = SQLCIPHER_LOG_NONE;
 
 sqlite3_mutex* sqlcipher_mutex(int mutex) {
@@ -1630,16 +1630,24 @@ int sqlcipher_codec_add_random(codec_ctx *ctx, const char *zRight, int random_sz
 }
 
 #if !defined(SQLITE_OMIT_TRACE)
+
+#define SQLCIPHER_PROFILE_FMT        "Elapsed time:%.3f ms - %s\n"
+#define SQLCIPHER_PROFILE_FMT_OSLOG  "Elapsed time:%{public}.3f ms - %{public}s\n"
+
 static int sqlcipher_profile_callback(unsigned int trace, void *file, void *stmt, void *run_time){
   FILE *f = (FILE*) file;
-  char *fmt = "Elapsed time:%.3f ms - %s\n";
   double elapsed = (*((sqlite3_uint64*)run_time))/1000000.0;
-#ifdef __ANDROID__
   if(f == NULL) {
-    __android_log_print(ANDROID_LOG_DEBUG, "sqlcipher", fmt, elapsed, sqlite3_sql((sqlite3_stmt*)stmt));
-  }
+#if !defined(SQLCIPHER_OMIT_LOG_DEVICE)
+#if defined(__ANDROID__)
+    __android_log_print(ANDROID_LOG_DEBUG, "sqlcipher", SQLCIPHER_PROFILE_FMT, elapsed, sqlite3_sql((sqlite3_stmt*)stmt));
+#elif defined(__APPLE__)
+    os_log(OS_LOG_DEFAULT, SQLCIPHER_PROFILE_FMT_OSLOG, elapsed, sqlite3_sql((sqlite3_stmt*)stmt));
 #endif
-  if(f) fprintf(f, fmt, elapsed, sqlite3_sql((sqlite3_stmt*)stmt));
+#endif
+  } else {
+    fprintf(f, SQLCIPHER_PROFILE_FMT, elapsed, sqlite3_sql((sqlite3_stmt*)stmt));
+  }
   return SQLITE_OK;
 }
 #endif
@@ -1656,8 +1664,8 @@ int sqlcipher_cipher_profile(sqlite3 *db, const char *destination){
       f = stdout;
     }else if(sqlite3_stricmp(destination, "stderr") == 0){
       f = stderr;
-    }else if(sqlite3_stricmp(destination, "logcat") == 0){
-      f = NULL; /* file pointer will be NULL indicating logcat on android */
+    }else if(sqlite3_stricmp(destination, "logcat") == 0 || sqlite3_stricmp(destination, "device") == 0){
+      f = NULL; /* file pointer will be NULL indicating the device target (i.e. logcat or oslog). We will accept logcat for backwards compatibility */
     }else{
 #if !defined(SQLCIPHER_PROFILE_USE_FOPEN) && (defined(_WIN32) && (__STDC_VERSION__ > 199901L) || defined(SQLITE_OS_WINRT))
       if(fopen_s(&f, destination, "a") != 0) return SQLITE_ERROR;
@@ -1686,20 +1694,49 @@ const char* sqlcipher_codec_get_provider_version(codec_ctx *ctx) {
 void sqlcipher_log(unsigned int level, const char *message, ...) {
   va_list params;
   va_start(params, message);
+  char *formatted = NULL;
 
 #ifdef CODEC_DEBUG
-#ifdef __ANDROID__
+#if defined(SQLCIPHER_OMIT_LOG_DEVICE)
+    vfprintf(stderr, message, params);
+    fprintf(stderr, "\n");
+    goto end;
+#else
+#if defined(__ANDROID__)
     __android_log_vprint(ANDROID_LOG_DEBUG, "sqlcipher", message, params);
+    goto end;
+#elif defined(__APPLE__)
+    formatted = sqlite3_vmprintf(message, params);
+    os_log(OS_LOG_DEFAULT, "%s", formatted);
+    sqlite3_free(formatted);
+    goto end;
 #else
     vfprintf(stderr, message, params);
     fprintf(stderr, "\n");
+    goto end;
+#endif
 #endif
 #endif
 
-  if(level > sqlcipher_log_level || (sqlcipher_log_logcat == 0 && sqlcipher_log_file == NULL)) {
+  if(level > sqlcipher_log_level || (sqlcipher_log_device == 0 && sqlcipher_log_file == NULL)) {
     /* no log target or tag not in included filters */
     goto end;
   }
+
+#if !defined(SQLCIPHER_OMIT_LOG_DEVICE)
+  if(sqlcipher_log_device) {
+#if defined(__ANDROID__)
+    __android_log_vprint(ANDROID_LOG_DEBUG, "sqlcipher", message, params);
+    goto end;
+#elif defined(__APPLE__)
+    formatted = sqlite3_vmprintf(message, params);
+    os_log(OS_LOG_DEFAULT, "%{public}s", formatted);
+    sqlite3_free(formatted);
+    goto end;
+#endif
+  }
+#endif
+
   if(sqlcipher_log_file != NULL){
     char buffer[24];
     struct tm tt;
@@ -1724,13 +1761,10 @@ void sqlcipher_log(unsigned int level, const char *message, ...) {
       fprintf((FILE*)sqlcipher_log_file, "%s.%03d: ", buffer, ms);
       vfprintf((FILE*)sqlcipher_log_file, message, params);
       fprintf((FILE*)sqlcipher_log_file, "\n");
+      goto end;
     }
   }
-#ifdef __ANDROID__
-  if(sqlcipher_log_logcat) {
-    __android_log_vprint(ANDROID_LOG_DEBUG, "sqlcipher", message, params);
-  }
-#endif
+
 end:
   va_end(params);
 }
@@ -1750,10 +1784,11 @@ int sqlcipher_set_log(const char *destination){
     fclose((FILE*)sqlcipher_log_file);
   }
   sqlcipher_log_file = NULL;
-  sqlcipher_log_logcat = 0;
+  sqlcipher_log_device = 0;
 
-  if(sqlite3_stricmp(destination, "logcat") == 0){
-    sqlcipher_log_logcat = 1;
+  if(sqlite3_stricmp(destination, "logcat") == 0 || sqlite3_stricmp(destination, "device") == 0){
+    /* use the appropriate device log. accept logcat for backwards compatibility */
+    sqlcipher_log_device = 1;
   } else if(sqlite3_stricmp(destination, "stdout") == 0){
     sqlcipher_log_file = stdout;
   }else if(sqlite3_stricmp(destination, "stderr") == 0){
